<p align="center">
  <img src="https://github.com/fast-aircraft-design/FAST-OAD/blob/master/docs/img/FAST_OAD_logo2.jpg?raw=true" alt="FAST-OAD logo" width="600">
</p>

# CS-25/FAR-25-related models


[![image](https://img.shields.io/pypi/v/fast-oad-cs25.svg)](https://pypi.python.org/pypi/fast-oad-cs25)
[![image](https://img.shields.io/pypi/pyversions/fast-oad-cs25.svg)](https://pypi.python.org/pypi/fast-oad-cs25)
[![License: GPL v3](https://img.shields.io/badge/License-GPLv3-blue.svg)](https://www.gnu.org/licenses/gpl-3.0)

![Tests](https://github.com/fast-aircraft-design/FAST-OAD_CS25/workflows/Tests/badge.svg)
[![Codacy Badge](https://app.codacy.com/project/badge/Grade/06d1fb8ee5c3429cb3cbb165413187bc)](https://app.codacy.com/gh/fast-aircraft-design/FAST-OAD_CS25/dashboard?utm_source=gh&utm_medium=referral&utm_content=&utm_campaign=Badge_grade)[![codecov](https://codecov.io/gh/fast-aircraft-design/FAST-OAD_CS25/branch/main/graph/badge.svg?token=91CIX996RD)](https://codecov.io/gh/fast-aircraft-design/FAST-OAD_CS25)
[![Ruff](https://img.shields.io/endpoint?url=https://raw.githubusercontent.com/astral-sh/ruff/main/assets/badge/v2.json)](https://github.com/astral-sh/ruff)

[![Documentation Status](https://readthedocs.org/projects/fast-oad-cs25/badge/?version=stable)](https://fast-oad-cs25.readthedocs.io/)
[![Binder](https://mybinder.org/badge_logo.svg)](https://mybinder.org/v2/gh/fast-aircraft-design/FAST-OAD_CS25.git/latest-release?urlpath=lab%2Ftree%2Fsrc%2Ffastoad_cs25%2Fnotebooks)


This package is a plugin for FAST-OAD (version 1.3 or above). It contains models related to classic
commercial transport aircraft.

## Want to try quickly?

You can run FAST-OAD-CS25 notebooks **without installation** using our
[Binder-hosted Jupyter notebooks](https://mybinder.org/v2/gh/fast-aircraft-design/FAST-OAD_CS25.git/latest-release?filepath=src%2Ffastoad_cs25%2Fnotebooks).


## Install

**Prerequisite**:FAST-OAD needs at least **Python 3.8.0**.

It is recommended (but not required) to do the install in a virtual
environment ([conda](https://docs.conda.io/en/latest/),
[venv](https://docs.python.org/3.7/library/venv.html), ...)

Once Python is installed, installation can be done using pip. FAST-OAD, the core software, will be
installed at the same time.

> **Note**: If your network uses a proxy, you may have to do [some
> settings](https://pip.pypa.io/en/stable/user_guide/#using-a-proxy-server)
> for pip to work correctly

You can install the latest version (including the main software FAST-OAD) with this command:

``` {.bash}
$ pip install --upgrade fast-oad-cs25
```
